betty.app.config module - Betty documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# betty.app.config module

Provide application configuration.

final class betty.app.config.AppConfiguration

  Bases: `Configuration`

  Provide configuration for `betty.app.App`.

  __init__(*, locale: str | None = None)
  dump() → DumpMapping[Dump]

    Produce a serialized data dump of `self`.

  load(dump: Dump) → None

    Load a serialized data dump into `self`.

    Raises:

      betty.assertion.error.AssertionFailed – Raised if the dump is invalid.

  property locale: str | None

    The application locale.